@@ -23,7 +23,7 @@ def has_faved(value, arg):
     user = value
     object = arg
     try:
-        fave = Fave.objects.get_for_model(object).get(user=user, object_id=object.id)
+        fave = Fave.objects.get_for_model(object).get(user=user, object_id=object.id, withdrawn=False)
     except Fave.DoesNotExist:
         return False
     
